@@ -21,67 +21,67 @@
 //
 //=========================================================
 
-#include "config.h"
+//#include "config.h"
 
 #include <stdio.h>
 #include <limits.h>
 #include "muse_math.h"
 
-#include <QComboBox>
+//#include <QComboBox>
 #include <QGridLayout>
-#include <QKeyEvent>
+//#include <QKeyEvent>
 #include <QLabel>
 #include <QList>
-#include <QMainWindow>
+//#include <QMainWindow>
 #include <QScrollBar>
 #include <QToolBar>
-#include <QVBoxLayout>
+//#include <QVBoxLayout>
 #include <QWheelEvent>
 #include <QPainter>
 #include <QCursor>
 #include <QPoint>
-#include <QRect>
+//#include <QRect>
 #include <QSettings>
 
 #include "arranger.h"
 #include "song.h"
 #include "app.h"
 #include "midiport.h"
-#include "mididev.h"
+//#include "mididev.h"
 #include "utils.h"
 #include "globals.h"
 #include "globaldefs.h"
 #include "icons.h"
-#include "utils.h"
+//#include "utils.h"
 #include "widget_stack.h"
 #include "audio.h"
-#include "event.h"
+//#include "event.h"
 #include "midiseq.h"
-#include "midictrl.h"
-#include "mpevent.h"
+//#include "midictrl.h"
+//#include "mpevent.h"
 #include "gconfig.h"
 #include "mixer/astrip.h"
 #include "mixer/mstrip.h"
 #include "shortcuts.h"
-#include "ttoolbutton.h"
+//#include "ttoolbutton.h"
 
 // Forwards from header:
-#include <QKeyEvent>
-#include <QPoint>
-#include <QComboBox>
-#include <QScrollBar>
-#include <QVBoxLayout>
-#include <QHBoxLayout>
+//#include <QKeyEvent>
+//#include <QPoint>
+//#include <QComboBox>
+//#include <QScrollBar>
+//#include <QVBoxLayout>
+//#include <QHBoxLayout>
 #include <QScrollArea>
 #include <QToolButton>
 #include "track.h"
-#include "part.h"
+//#include "part.h"
 #include "xml.h"
 #include "rasterizer.h"
-#include "lcombo.h"
+//#include "lcombo.h"
 #include "mtscale.h"
 #include "arrangerview.h"
-#include "astrip.h"
+//#include "astrip.h"
 #include "header.h"
 #include "poslabel.h"
 #include "scrollscale.h"
@@ -313,6 +313,7 @@ Arranger::Arranger(ArrangerView* parent, const char* name)
       // by overflows in tick computations
       lenEntry = new SpinBox(1, 10000, 1);
       lenEntry->setFocusPolicy(Qt::StrongFocus);
+      lenEntry->setKeyboardTracking(false);
       lenEntry->setValue(MusEGlobal::song->len());
       lenEntry->setToolTip(tr("Song length - bars"));
       lenEntry->setWhatsThis(tr("Song length - bars"));
@@ -325,6 +326,7 @@ Arranger::Arranger(ArrangerView* parent, const char* name)
       
       globalPitchSpinBox = new SpinBox(-127, 127, 1);
       globalPitchSpinBox->setFocusPolicy(Qt::StrongFocus);
+      globalPitchSpinBox->setKeyboardTracking(false);
       globalPitchSpinBox->setValue(MusEGlobal::song->globalPitchShift());
       globalPitchSpinBox->setToolTip(tr("Midi pitch"));
       globalPitchSpinBox->setWhatsThis(tr("Global midi pitch shift"));
@@ -337,6 +339,7 @@ Arranger::Arranger(ArrangerView* parent, const char* name)
       
       globalTempoSpinBox = new SpinBox(50, 200, 1, toolbar);
       globalTempoSpinBox->setFocusPolicy(Qt::StrongFocus);
+      globalTempoSpinBox->setKeyboardTracking(false);
       globalTempoSpinBox->setSuffix(QString("%"));
       globalTempoSpinBox->setValue(MusEGlobal::tempomap.globalTempo());
       globalTempoSpinBox->setToolTip(tr("Midi tempo"));
@@ -761,7 +764,7 @@ void Arranger::songChanged(MusECore::SongChangedStruct_t type)
               }   
             } 
           }
-          
+
           {
             MidiStrip* w = static_cast<MidiStrip*>(trackInfoWidget->getWidget(2));
             if(w)
@@ -779,12 +782,22 @@ void Arranger::songChanged(MusECore::SongChangedStruct_t type)
               }   
             } 
           }
+
+            bool trackArmed = false;
+            for (const auto& it : *MusEGlobal::song->tracks()) {
+                if (it->canRecord() && it->recordFlag()) {
+                    trackArmed = true;
+                    break;
+                }
+            }
+            if (!trackArmed)
+                MusEGlobal::song->setRecord(false);
         }
         
         // Try these, may need more/less. 
         if(type & ( SC_TRACK_INSERTED | SC_TRACK_REMOVED | SC_TRACK_MODIFIED | SC_TRACK_MOVED |
            SC_PART_INSERTED | SC_PART_REMOVED | SC_PART_MODIFIED |
-           SC_SIG))
+           SC_SIG | SC_DIVISION_CHANGED))
         {
           unsigned endTick = MusEGlobal::song->len();
           int offset  = MusEGlobal::sigmap.ticksMeasure(endTick);
@@ -1284,11 +1297,8 @@ void Arranger::switchInfo(int n)
                     w->setBroadcastChanges(true);
 
                     // Set focus yielding to the canvas.
-                    if(MusEGlobal::config.smartFocus)
-                    {
-                      w->setFocusYieldWidget(canvas);
-                      //w->setFocusPolicy(Qt::WheelFocus);
-                    }
+                    w->setFocusYieldWidget(canvas);
+                    //w->setFocusPolicy(Qt::WheelFocus);
 
                     // We must marshall song changed instead of connecting to the strip's song changed
                     //  otherwise it crashes when loading another song because track is no longer valid
@@ -1329,11 +1339,8 @@ void Arranger::switchInfo(int n)
                   // Broadcast changes to other selected tracks.
                   w->setBroadcastChanges(true);
                   // Set focus yielding to the arranger canvas.
-                  if(MusEGlobal::config.smartFocus)
-                  {
-                    w->setFocusYieldWidget(canvas);
-                    //w->setFocusPolicy(Qt::WheelFocus);
-                  }
+                  w->setFocusYieldWidget(canvas);
+                  //w->setFocusPolicy(Qt::WheelFocus);
 
                   // No. See above.
                   //connect(MusEGlobal::song, SIGNAL(songChanged(MusECore::SongChangedStruct_t)), w, SLOT(songChanged(MusECore::SongChangedStruct_t)));
