@@ -85,8 +85,8 @@
 #define DEBUG_TRANSPORT_SYNC(dev, format, args...) // fprintf(dev, format, ##args);
 
 namespace MusEGlobal {
-MusECore::Audio* audio = NULL;
-MusECore::AudioDevice* audioDevice = NULL;   // current audio device in use
+MusECore::Audio* audio = nullptr;
+MusECore::AudioDevice* audioDevice = nullptr;   // current audio device in use
 extern unsigned int volatile midiExtSyncTicks;   
 }
 
@@ -113,7 +113,7 @@ const char* seqMsgList[] = {
       "AUDIO_ROUTEADD", "AUDIO_ROUTEREMOVE", "AUDIO_REMOVEROUTES",
       "AUDIO_ADDPLUGIN",
       "AUDIO_SET_PREFADER", "AUDIO_SET_CHANNELS",
-      "AUDIO_SWAP_CONTROLLER_IDX",
+      "AUDIO_SWAP_PLUGINS",
       "AUDIO_CLEAR_CONTROLLER_EVENTS",
       "AUDIO_SEEK_PREV_AC_EVENT",
       "AUDIO_SEEK_NEXT_AC_EVENT",
@@ -235,10 +235,8 @@ bool Audio::start()
       state = STOP;
       _loopCount = 0;
       
-      //MusEGlobal::muse->setHeartBeat();  // Moved below
-      
       if (!MusEGlobal::audioDevice) {
-          if(initJackAudio() == false) {
+          if(initJackAudio() == true) {
                 InputList* itl = MusEGlobal::song->inputs();
                 for (iAudioInput i = itl->begin(); i != itl->end(); ++i) {
                       if (MusEGlobal::debugMsg) fprintf(stderr, "reconnecting input %s\n", (*i)->name().toLatin1().data());
@@ -790,7 +788,7 @@ void Audio::process(unsigned frames)
                 !MusEGlobal::tempomap.masterFlag() &&
                 !MusEGlobal::extSyncFlag &&
                 static_cast<MusECore::JackAudioDevice*>(MusEGlobal::audioDevice)->timebaseQuery(
-                  frames, NULL, NULL, NULL, &curr_jt_tick, &next_jt_ticks);
+                  frames, nullptr, nullptr, nullptr, &curr_jt_tick, &next_jt_ticks);
             // NOTE: I would rather trust the reported current tick than rely solely on the stream of 
             // tempos to correctly advance to the next position (which did actually test OK anyway).
             if(use_jack_timebase)
@@ -1455,8 +1453,8 @@ void Audio::processMsg(AudioMsg* msg)
             case AUDIO_ADDPLUGIN:
                   msg->snode->addPlugin(msg->plugin, msg->ival);
                   break;
-            case AUDIO_SWAP_CONTROLLER_IDX:
-                  msg->snode->swapControllerIDX(msg->a, msg->b);
+            case AUDIO_SWAP_PLUGINS:
+                  msg->snode->swapPlugins(msg->a, msg->b);
                   break;
             case AUDIO_CLEAR_CONTROLLER_EVENTS:
                   msg->snode->clearControllerEvents(msg->ival);
@@ -1589,7 +1587,7 @@ void Audio::seek(const Pos& p)
           !MusEGlobal::tempomap.masterFlag() &&
           !MusEGlobal::extSyncFlag &&
           static_cast<MusECore::JackAudioDevice*>(MusEGlobal::audioDevice)->timebaseQuery(
-              MusEGlobal::segmentSize, NULL, NULL, NULL, &curr_jt_tick, NULL))
+              MusEGlobal::segmentSize, nullptr, nullptr, nullptr, &curr_jt_tick, nullptr))
           curTickPos = curr_jt_tick;
         else
   #endif
