@@ -361,8 +361,18 @@ Appearance::Appearance(QWidget* parent)
       QStringList fileTypes;
       fileTypes.append("*.qss");
       QFileInfoList list = themeDir.entryInfoList(fileTypes);
-      for (const auto& item : list)
+      for (const auto& item : qAsConst(list))
           themeComboBox->addItem(item.baseName());
+
+      themeDir.setPath(MusEGlobal::configPath + QString("/themes"));
+      if (themeDir.exists()) {
+          list = themeDir.entryInfoList(fileTypes);
+          for (const auto& item : qAsConst(list)) {
+              if (themeComboBox->findText(item.baseName()) == -1)
+              themeComboBox->addItem(item.baseName());
+          }
+      }
+
       themeComboBox->setCurrentText(MusEGlobal::config.theme);
 
       //---------------------------------------------------
