@@ -520,7 +520,7 @@ void CompactSlider::getScrollMode( QPoint &p, const Qt::MouseButton &button, con
 {
   // If modifier or button is held, jump directly to the position at first.
   // After handling it, the caller can change to SrcMouse scroll mode.
-  if(modifiers & Qt::ControlModifier || button == Qt::MidButton)
+  if(modifiers & Qt::ControlModifier || button == Qt::MiddleButton)
   {
     scrollMode = ScrDirect;
     direction = 0;
