@@ -22,10 +22,10 @@
 //
 //=========================================================
 
-#include <stdio.h>
+//#include <stdio.h>
 
 #include <QFileDialog>
-#include <QFileInfo>
+//#include <QFileInfo>
 #include <QRect>
 #include <QShowEvent>
 #include <QString>
@@ -38,19 +38,19 @@
 #include "icons.h"
 #include "helper.h"
 #include "filedialog.h"
-#include "al/al.h"
+//#include "al/al.h"
 #include "undo.h"
 
 #include "song.h"
 #include "operations.h"
 #include "audio.h"
 #include "audio_converter_settings.h"
-#include "audio_convert/audio_converter_plugin.h"
+//#include "audio_convert/audio_converter_plugin.h"
 #include "audio_convert/audio_converter_settings_group.h"
 
 // Forwards from header:
 #include <QButtonGroup>
-#include <QShowEvent>
+//#include <QShowEvent>
 #include <QWidget>
 
 namespace MusEGui {
@@ -225,10 +225,14 @@ void GlobalSettingsConfig::updateSettings()
       
       recDrumGroup->button(MusEGlobal::config.newDrumRecordCondition)->setChecked(true);
 
+      cbEnableLash->setChecked(MusEGlobal::config.enableLash);
+#ifndef HAVE_LASH
+      cbEnableLash->setEnabled(false);
+#endif
+
       showSplash->setChecked(MusEGlobal::config.showSplashScreen);
       showDidYouKnow->setChecked(MusEGlobal::config.showDidYouKnow);
       externalWavEditorSelect->setText(MusEGlobal::config.externalWavEditor);
-      oldStyleStopCheckBox->setChecked(MusEGlobal::config.useOldStyleStopShortCut);
       moveArmedCheckBox->setChecked(MusEGlobal::config.moveArmedCheckBox);
       projectSaveCheckBox->setChecked(MusEGlobal::config.useProjectSaveDialog);
       popsDefStayOpenCheckBox->setChecked(MusEGlobal::config.popupsDefaultStayOpen);
@@ -267,6 +271,9 @@ void GlobalSettingsConfig::updateSettings()
       cbTabWave->setChecked(TopWin::_openTabbed[TopWin::WAVE]);
       cbTabScore->setChecked(TopWin::_openTabbed[TopWin::SCORE]);
       cbTabMaster->setChecked(TopWin::_openTabbed[TopWin::MASTER]);
+
+      cbAMixerDocked->setChecked(MusEGlobal::config.mixerDockedA);
+      cbBMixerDocked->setChecked(MusEGlobal::config.mixerDockedB);
 }
 
 //---------------------------------------------------------
@@ -340,10 +347,11 @@ void GlobalSettingsConfig::apply()
       MusEGlobal::config.showNoteTooltips = showNoteTooltipsCheckBox->isChecked();
       MusEGlobal::config.showTimeScaleBeatNumbers = showTimeScaleBeatNumbersCheckBox->isChecked();
       MusEGlobal::config.preferMidiVolumeDb = preferMidiVolumeDbCheckBox->isChecked();
+
       MusEGlobal::config.showSplashScreen = showSplash->isChecked();
+      MusEGlobal::config.enableLash = cbEnableLash->isChecked();
       MusEGlobal::config.showDidYouKnow   = showDidYouKnow->isChecked();
       MusEGlobal::config.externalWavEditor = externalWavEditorSelect->text();
-      MusEGlobal::config.useOldStyleStopShortCut = oldStyleStopCheckBox->isChecked();
       MusEGlobal::config.moveArmedCheckBox = moveArmedCheckBox->isChecked();
       MusEGlobal::config.useProjectSaveDialog = projectSaveCheckBox->isChecked();
       MusEGlobal::config.popupsDefaultStayOpen = popsDefStayOpenCheckBox->isChecked();
@@ -397,6 +405,9 @@ void GlobalSettingsConfig::apply()
       TopWin::_openTabbed[TopWin::SCORE] = cbTabScore->isChecked();
       TopWin::_openTabbed[TopWin::MASTER] = cbTabMaster->isChecked();
 
+      MusEGlobal::config.mixerDockedA = cbAMixerDocked->isChecked();
+      MusEGlobal::config.mixerDockedB = cbBMixerDocked->isChecked();
+
       // If the division is to be changed, this will RE-NORMALIZE things like the tempo and signature lists,
       //  and RE-FILL the various editor rasterization (snap) table values.
       // The various editors will respond and deal with changing each of their local raster values.
