@@ -29,9 +29,9 @@
 #include <QIcon>
 #include <QMessageBox>
 
-#include <stdio.h>
+//#include <stdio.h>
 #include "metronome.h"
-#include "midi_consts.h"
+//#include "midi_consts.h"
 #include "ticksynth.h"
 
 #include "globals.h"
@@ -328,11 +328,18 @@ void MetronomeConfig::fillSoundFiles()
     MusECore::MetronomeSettings* metro_settings = 
       MusEGlobal::metroUseSongSettings ? &MusEGlobal::metroSongSettings : &MusEGlobal::metroGlobalSettings;
 
-    QDir metroPath(MusEGlobal::museGlobalShare+"/metronome");
+    QDir metroPath(MusEGlobal::museGlobalShare + "/metronome");
+    QDir localMetroPath(MusEGlobal::configPath + "/metronome");
+
     QStringList filters;
     filters.append("*.wav");
-    QStringList klickfiles = metroPath.entryList(filters);
 
+    QStringList klickfiles = metroPath.entryList(filters);
+    QStringList klickfiles2 = localMetroPath.entryList(filters);
+
+    for (auto filestr: klickfiles2) {
+        klickfiles.append(filestr + METRO_USER_STR);
+    }
     measSampleCombo->clear();
     beatSampleCombo->clear();
     accent1SampleCombo->clear();
