@@ -61,7 +61,6 @@
 #include "lv2/lv2plug.in/ns/ext/patch/patch.h"
 #include "lv2/lv2plug.in/ns/ext/port-groups/port-groups.h"
 #include "lv2/lv2plug.in/ns/ext/presets/presets.h"
-#include "lv2/lv2plug.in/ns/ext/state/state.h"
 #include "lv2/lv2plug.in/ns/ext/time/time.h"
 #ifdef LV2_URI_MAP_SUPPORT
 #include "lv2/lv2plug.in/ns/ext/uri-map/uri-map.h"
@@ -282,9 +281,9 @@ struct LV2ControlPort
    ~LV2ControlPort()
    {
       free ( cName );      
-      cName = NULL;
+      cName = nullptr;
       free(cSym);
-      cSym = NULL;
+      cSym = nullptr;
    }
    const LilvPort *port;
    uint32_t index; //plugin real port index
@@ -295,7 +294,7 @@ struct LV2ControlPort
    char *cSym; //cached port symbol
    LV2ControlPortType cType;
    bool isCVPort;
-   CtrlEnumValues* scalePoints;
+   const CtrlEnumValues* scalePoints;
    QString group;
    bool isTrigger;
    bool notOnGui;
@@ -419,6 +418,7 @@ private:
     uint32_t _fDataAccess;
     uint32_t _fWrkSchedule;
     uint32_t _fUiResize;
+    uint32_t _fUiRequestValue;
     uint32_t _fPrgHost;
 #ifdef MIDNAM_SUPPORT
     uint32_t _fMidNamUpdate;
@@ -427,7 +427,9 @@ private:
     uint32_t _fMakePath;
 #endif
     uint32_t _fMapPath;
-    //const LilvNode *_pluginUIType = NULL;
+    uint32_t _fLoadDefaultState;
+
+    //const LilvNode *_pluginUIType = nullptr;
 
     LV2_URID _uTime_Position;
     LV2_URID _uTime_frame;
@@ -481,6 +483,8 @@ public:
     bool usesTimePosition() const { return _usesTimePosition; }
     static void lv2ui_PostShow ( LV2PluginWrapper_State *state );
     static int lv2ui_Resize ( LV2UI_Feature_Handle handle, int width, int height );
+    static LV2UI_Request_Value_Status lv2ui_Request_Value (
+      LV2UI_Feature_Handle handle, LV2_URID key, LV2_URID type, const LV2_Feature *const *features );
     static void lv2ui_Gtk2AllocateCb(int width, int height, void *arg);
     static void lv2ui_Gtk2ResizeCb(int width, int height, void *arg);
     static void lv2ui_ShowNativeGui (LV2PluginWrapper_State *state, bool bShow , bool fixScaling);
@@ -620,7 +624,7 @@ public:
     const char *paramOutName ( unsigned long i );
     CtrlValueType ctrlValueType ( unsigned long ) const override;
     CtrlList::Mode ctrlMode ( unsigned long ) const override;
-    CtrlEnumValues *ctrlEnumValues(unsigned long i) const override;
+    const CtrlEnumValues *ctrlEnumValues(unsigned long i) const override;
     QString portGroup(long unsigned int i) const override;
     bool ctrlIsTrigger(long unsigned int i) const override;
     bool ctrlNotOnGui(long unsigned int i) const override;
@@ -723,10 +727,13 @@ struct LV2PluginWrapper_State {
       uiIsOpening(false),
       operationsFifo(OPERATIONS_FIFO_SIZE)
    {
-      extHost.plugin_human_id = NULL;
-      extHost.ui_closed = NULL;
+      extHost.plugin_human_id = nullptr;
+      extHost.ui_closed = nullptr;
       uiResize.handle = (LV2UI_Feature_Handle)this;
       uiResize.ui_resize = LV2Synth::lv2ui_Resize;
+      uiRequestValue.handle = (LV2UI_Feature_Handle)this;
+      uiRequestValue.request = LV2Synth::lv2ui_Request_Value;
+
       prgHost.handle = (LV2_Programs_Handle)this;
       prgHost.program_changed = LV2SynthIF::lv2prg_Changed;
 #ifdef MIDNAM_SUPPORT
@@ -797,6 +804,7 @@ struct LV2PluginWrapper_State {
     LV2UI_Idle_Interface *uiIdleIface;
     const LilvUI *uiCurrent;    
     LV2UI_Resize uiResize;
+    LV2UI_Request_Value uiRequestValue;
     QSize uiX11Size;
     LV2PluginWrapper_Window *pluginWindow;
     QWindow *pluginQWindow;
@@ -916,7 +924,7 @@ public:
     virtual double defaultValue ( unsigned long port ) const;
     virtual const char *portName ( unsigned long i );
     virtual CtrlValueType ctrlValueType ( unsigned long ) const;
-    virtual CtrlEnumValues* ctrlEnumValues ( unsigned long ) const;
+    virtual const CtrlEnumValues* ctrlEnumValues ( unsigned long ) const;
     virtual CtrlList::Mode ctrlMode ( unsigned long ) const;
     virtual bool hasNativeGui() const;
     virtual void showNativeGui ( PluginI *p, bool bShow );
