@@ -23,7 +23,6 @@
 #include "masteredit.h"
 #include "utils.h"
 #include "lcombo.h"
-#include "doublelabel.h"
 #include "globals.h"
 #include "app.h"
 #include "gconfig.h"
@@ -33,14 +32,14 @@
 
 #include <limits.h>
 
-#include <QActionGroup>
+//#include <QActionGroup>
 #include <QGridLayout>
 #include <QLabel>
 #include <QMenuBar>
 #include <QMenu>
 #include <QList>
-#include <QHeaderView>
-#include <QListView>
+//#include <QHeaderView>
+//#include <QListView>
 
 // Forwards from header:
 #include <QCloseEvent>
