@@ -22,19 +22,19 @@
 //=========================================================
 
 #include <stdio.h>
-#include <errno.h>
+//#include <errno.h>
 #include <limits.h>
-#include <sys/stat.h>
-#include <sys/types.h>
+//#include <sys/stat.h>
+//#include <sys/types.h>
 #ifndef _WIN32
 #include <sys/mman.h>
 #endif
 
 #include <QByteArray>
-#include <QSet>
+//#include <QSet>
 #include <QMimeData>
 
-#include "xml.h"
+//#include "xml.h"
 #include "ecanvas.h"
 #include "song.h"
 #include "shortcuts.h"
@@ -47,7 +47,7 @@
 #include "config.h"
 
 // Forwards from header:
-#include <QDropEvent>
+//#include <QDropEvent>
 #include <QEvent>
 #include <QKeyEvent>
 #include <QToolTip>
@@ -178,12 +178,12 @@ void EventCanvas::updateItems()
     storedEvent=curItem->event();
     partSn=curItem->part()->sn();
   }
-  curItem=NULL;
+  curItem=nullptr;
   
   items.clearDelete();
   start_tick  = INT_MAX;
   end_tick    = 0;
-  curPart = 0;
+  curPart = nullptr;
   for (MusECore::iPart p = editor->parts()->begin(); p != editor->parts()->end(); ++p) {
         MusECore::MidiPart* part = (MusECore::MidiPart*)(p->second);
         if (part->sn() == curPartId)
@@ -217,7 +217,7 @@ void EventCanvas::updateItems()
                     
                     if (temp && curItemNeedsRestore && e==storedEvent && part->sn()==partSn)
                     {
-                        if (curItem!=NULL)
+                        if (curItem!=nullptr)
                           fprintf(stderr, "THIS SHOULD NEVER HAPPEN: curItemNeedsRestore=true, event fits, but there was already a fitting event!?\n");
                         
                         curItem=temp;
@@ -508,16 +508,24 @@ void EventCanvas::keyPress(QKeyEvent* event)
               }
             }
       else if (key == shortcuts[SHRT_INC_PITCH].key) {
+          if(_playEvents)
+              stopPlayEvents();
             modifySelected(NoteInfo::VAL_PITCH, 1);
             }
       else if (key == shortcuts[SHRT_DEC_PITCH].key) {
+          if(_playEvents)
+              stopPlayEvents();
             modifySelected(NoteInfo::VAL_PITCH, -1);
             }
       else if (key == shortcuts[SHRT_INC_POS].key) {
+          if(_playEvents)
+              stopPlayEvents();
             // TODO: Check boundaries
             modifySelected(NoteInfo::VAL_TIME, editor->raster());
             }
       else if (key == shortcuts[SHRT_DEC_POS].key) {
+          if(_playEvents)
+              stopPlayEvents();
             // TODO: Check boundaries
             modifySelected(NoteInfo::VAL_TIME, 0 - editor->raster());
             }
@@ -543,6 +551,9 @@ void EventCanvas::keyPress(QKeyEvent* event)
 void EventCanvas::keyRelease(QKeyEvent* event)
 {
       const int key = event->key();
+
+      if(_playEvents && key == Qt::Key_Control)
+          stopPlayEvents();
       
       // We do not want auto-repeat events.
       // It does press and release repeatedly. Wait till the last release comes.
