@@ -27,16 +27,16 @@
 #include <QPair>
 #include <QToolTip>
 
-#include <set>
+//#include <QDebug>
 
-#include <limits.h>
+//#include <limits.h>
 #include <stdio.h>
 #include "muse_math.h"
-#include <errno.h>
+//#include <errno.h>
 
 #include "prcanvas.h"
-#include "view.h"
-#include "mpevent.h"
+//#include "view.h"
+//#include "mpevent.h"
 #include "globals.h"
 #include "cmd.h"
 #include "song.h"
@@ -48,17 +48,17 @@
 #include "type_defs.h"
 
 // Forwards from header:
-#include <QDragEnterEvent>
-#include <QDropEvent>
-#include <QMouseEvent>
+//#include <QDragEnterEvent>
+//#include <QDropEvent>
+//#include <QMouseEvent>
 #include <QDragMoveEvent>
-#include <QDragLeaveEvent>
-#include <QResizeEvent>
+//#include <QDragLeaveEvent>
+//#include <QResizeEvent>
 #include <QPainter>
 #include <QWidget>
 #include "part.h"
 #include "event.h"
-#include "pianoroll.h"
+//#include "pianoroll.h"
 #include "midieditor.h"
 #include "citem.h"
 #include "scrollscale.h"
@@ -86,7 +86,7 @@ NEvent::NEvent(const MusECore::Event& e, MusECore::Part* p, int y) : EItem(e, p)
 
 void PianoCanvas::setLastEdited(MusECore::Event& e)
 {
-    if (lastEditedEvent==0)
+    if (lastEditedEvent==nullptr)
         lastEditedEvent = new MusECore::Event();
     *lastEditedEvent = e.clone();
 }
@@ -99,7 +99,7 @@ CItem* PianoCanvas::addItem(MusECore::Part* part, const MusECore::Event& event)
       {
 //       if (signed(event.tick())<0) {
 //             printf("ERROR: trying to add event before current part!\n");
-//             return NULL;
+//             return nullptr;
 //       }
 
       NEvent* ev = new NEvent(event, part, pitch2y(event.pitch()));
@@ -986,7 +986,7 @@ CItem* PianoCanvas::newItem(const QPoint& p, int state)
       int eventVelocity = curVelo;
 
       // if option is enabled and there was a prior event we clone velocity and length from that event
-      if (MusEGlobal::config.useLastEditedEvent && lastEditedEvent != 0)
+      if (MusEGlobal::config.useLastEditedEvent && lastEditedEvent != nullptr)
       {
           // curVelo = lastEditedEvent->velo(); currently not used, last changed velocity overrides it, haven't quite figured out how.
           len = lastEditedEvent->lenTick();
@@ -994,7 +994,7 @@ CItem* PianoCanvas::newItem(const QPoint& p, int state)
 
       tick     -= curPart->tick();
       if (tick < 0)
-            return 0;
+            return nullptr;
       MusECore::Event e =  MusECore::Event(MusECore::Note);
       e.setTick(tick);
       e.setPitch(pitch);
@@ -1179,7 +1179,7 @@ void PianoCanvas::pianoCmd(int cmd)
                   MusEGlobal::song->setPos(MusECore::Song::CPOS, p, true, true, true); //CDW
                   }
                   break;
-            case CMD_INSERT:
+            case CMD_PUSH:
                   {
                   if (pos[0] < start() || pos[0] >= end())
                         break;
@@ -1206,7 +1206,7 @@ void PianoCanvas::pianoCmd(int cmd)
                   MusEGlobal::song->setPos(MusECore::Song::CPOS, p, true, false, true);
                   }
                   return;
-            case CMD_BACKSPACE:
+            case CMD_PULL:
                   if (pos[0] < start() || pos[0] >= end())
                         break;
                   {
@@ -1246,7 +1246,8 @@ void PianoCanvas::pianoPressed(int pitch, int velocity, bool shift)
         velocity = 1;
       
       // Stop all notes.
-      stopPlayEvents();
+      if (!shift)
+          stopPlayEvents();
 
       // play note:
       if(_playEvents)
@@ -1255,7 +1256,7 @@ void PianoCanvas::pianoPressed(int pitch, int velocity, bool shift)
       }
       
       if (_steprec && curPart) // && pos[0] >= start_tick && pos[0] < end_tick [removed by flo93: this is handled in steprec->record]
-                 steprec->record(curPart,pitch,editor->raster(),editor->raster(),velocity,MusEGlobal::globalKeyState&Qt::ControlModifier,shift, -1 /* anything which is != rcSteprecNote */);
+          steprec->record(curPart,pitch,editor->raster(),editor->raster(),velocity,MusEGlobal::globalKeyState&Qt::ControlModifier,shift, -1 /* anything which is != rcSteprecNote */);
       }
 
 //---------------------------------------------------------
@@ -1263,11 +1264,22 @@ void PianoCanvas::pianoPressed(int pitch, int velocity, bool shift)
 //---------------------------------------------------------
 
 void PianoCanvas::pianoReleased(int /*pitch*/, bool)
-      {
-      // release key:
-      if(_playEvents)
+{
+    // release key:
+    if(_playEvents)
         stopPlayEvents();
-      }
+}
+
+void PianoCanvas::pianoShiftReleased()
+{
+    if (_playEvents)
+        stopPlayEvents();
+
+    if (_steprec && curPart) {
+        steprec->moveon(editor->raster());
+    }
+}
+
 
 // NOTE Keep this for now in case we can get it to work...
 #if 0
@@ -1754,95 +1766,116 @@ void PianoCanvas::curPartChanged()
 //---------------------------------------------------------
 
 void PianoCanvas::modifySelected(MusEGui::NoteInfo::ValType type, int val, bool delta_mode)
-      {
-      QList< QPair<int,MusECore::Event> > already_done;
-      MusECore::Undo operations;
+{
+    QList< QPair<int,MusECore::Event> > already_done;
+    MusECore::Undo operations;
+    unsigned int playedEventTick = UINT_MAX;
 
-      for (iCItem i = items.begin(); i != items.end(); ++i) {
-            if (!(i->second->isSelected()))
-                  continue;
-            NEvent* e   = (NEvent*)(i->second);
-            MusECore::Event event = e->event();
-            if (event.type() != MusECore::Note)
-                  continue;
+    for (const auto& i : qAsConst(items)) {
+        if (!(i.second->isSelected()))
+            continue;
+        NEvent* e   = (NEvent*)(i.second);
+        MusECore::Event event = e->event();
+        if (event.type() != MusECore::Note)
+            continue;
 
-            MusECore::MidiPart* part = (MusECore::MidiPart*)(e->part());
+        MusECore::MidiPart* part = (MusECore::MidiPart*)(e->part());
 
-            if (already_done.contains(QPair<int,MusECore::Event>(part->clonemaster_sn(), event)))
-              continue;
+        if (already_done.contains(QPair<int,MusECore::Event>(part->clonemaster_sn(), event)))
+            continue;
 
-            MusECore::Event newEvent = event.clone();
+        MusECore::Event newEvent = event.clone();
 
-            switch (type) {
-                  case MusEGui::NoteInfo::VAL_TIME:
-                        {
-                        int newTime = val;
-                        if(delta_mode)
-                          newTime += event.tick();
-                        else
-                          newTime -= part->tick();
-                        if (newTime < 0)
-                           newTime = 0;
-                        newEvent.setTick(newTime);
+        switch (type) {
+            case MusEGui::NoteInfo::VAL_TIME:
+                {
+                    int newTime = val;
+                    if(delta_mode)
+                        newTime += event.tick();
+                    else
+                        newTime -= part->tick();
+                    if (newTime < 0)
+                        newTime = 0;
+                    newEvent.setTick(newTime);
+
+                    if (_playEvents) {
+                        if (playedEventTick == UINT_MAX) {
+                            playedEventTick = newEvent.tick();
+                            startPlayEvent(newEvent.pitch(), newEvent.velo());
+                        } else if (_playEventsMode == PlayEventsChords) {
+                            if (playedEventTick == newEvent.tick())
+                                startPlayEvent(newEvent.pitch(), newEvent.velo());
                         }
-                        break;
-                  case MusEGui::NoteInfo::VAL_LEN:
-                        {
-                        int len = val;
-                        if(delta_mode)
-                          len += event.lenTick();
-                        if (len < 1)
-                              len = 1;
-                        newEvent.setLenTick(len);
-                        }
-                        break;
-                  case MusEGui::NoteInfo::VAL_VELON:
-                        {
-                        int velo = val;
-                        if(delta_mode)
-                          velo += event.velo();
-                        if (velo > 127)
-                              velo = 127;
-                        else if (velo < 0)
-                              // REMOVE Tim. Noteoff. Changed. Zero note on vel is not allowed now.
-//                               velo = 0;
-                              velo = 1;
-                        newEvent.setVelo(velo);
-                        }
-                        break;
-                  case MusEGui::NoteInfo::VAL_VELOFF:
-                        {
-                        int velo = val;
-                        if(delta_mode)
-                          velo += event.veloOff();
-                        if (velo > 127)
-                              velo = 127;
-                        else if (velo < 0)
-                              velo = 0;
-                        newEvent.setVeloOff(velo);
-                        }
-                        break;
-                  case MusEGui::NoteInfo::VAL_PITCH:
-                        {
-                        int pitch = val;
-                        if(delta_mode)
-                          pitch += event.pitch();
-                        if (pitch > 127)
-                              pitch = 127;
-                        else if (pitch < 0)
-                              pitch = 0;
-                        newEvent.setPitch(pitch);
-                        }
-                        break;
-                  }
-            operations.push_back(MusECore::UndoOp(MusECore::UndoOp::ModifyEvent, newEvent, event, part, false, false));
-            already_done.append(QPair<int,MusECore::Event>(part->clonemaster_sn(), event));
+                    }
+                }
+                break;
+            case MusEGui::NoteInfo::VAL_LEN:
+                {
+                    int len = val;
+                    if(delta_mode)
+                        len += event.lenTick();
+                    if (len < 1)
+                        len = 1;
+                    newEvent.setLenTick(len);
+                }
+                break;
+            case MusEGui::NoteInfo::VAL_VELON:
+                {
+                    int velo = val;
+                    if(delta_mode)
+                        velo += event.velo();
+                    if (velo > 127)
+                        velo = 127;
+                    else if (velo < 0)
+                        // REMOVE Tim. Noteoff. Changed. Zero note on vel is not allowed now.
+                        //                               velo = 0;
+                        velo = 1;
+                    newEvent.setVelo(velo);
+                }
+                break;
+            case MusEGui::NoteInfo::VAL_VELOFF:
+                {
+                    int velo = val;
+                    if(delta_mode)
+                        velo += event.veloOff();
+                    if (velo > 127)
+                        velo = 127;
+                    else if (velo < 0)
+                        velo = 0;
+                    newEvent.setVeloOff(velo);
+                }
+                break;
+            case MusEGui::NoteInfo::VAL_PITCH:
+                {
+                    int pitch = val;
+                    if(delta_mode)
+                        pitch += event.pitch();
+                    if (pitch > 127)
+                        pitch = 127;
+                    else if (pitch < 0)
+                        pitch = 0;
+                    newEvent.setPitch(pitch);
 
-            //setLastEdited(newEvent);
-            }
-      MusEGlobal::song->applyOperationGroup(operations);
+                    if (_playEvents) {
+                        if (playedEventTick == UINT_MAX) {
+                            playedEventTick = newEvent.tick();
+                            startPlayEvent(pitch, newEvent.velo());
+                        } else if (_playEventsMode == PlayEventsChords) {
+                            if (playedEventTick == newEvent.tick())
+                                startPlayEvent(pitch, newEvent.velo());
+                        }
+                    }
+                }
+                break;
+        }
 
-      }
+        operations.push_back(MusECore::UndoOp(MusECore::UndoOp::ModifyEvent, newEvent, event, part, false, false));
+        already_done.append(QPair<int,MusECore::Event>(part->clonemaster_sn(), event));
+
+        //setLastEdited(newEvent);
+    }
+    MusEGlobal::song->applyOperationGroup(operations);
+}
 
 //---------------------------------------------------------
 //   resizeEvent
