@@ -23,7 +23,7 @@
 #include "midieditor.h"
 #include "globals.h"
 #include "midiedit/ecanvas.h"
-#include "waveedit/waveview.h"
+//#include "waveedit/waveview.h"
 #include "scrollscale.h"
 #include "mtscale.h"
 #include "xml.h"
@@ -32,7 +32,7 @@
 #include "song.h"
 
 #include "trackinfo_layout.h"
-#include "icons.h"
+//#include "icons.h"
 #include "astrip.h"
 #include "mstrip.h"
 #include "gconfig.h"
@@ -40,10 +40,10 @@
 #include "rasterizer.h"
 
 #include <QRect>
-#include <QColor>
+//#include <QColor>
 #include <QGridLayout>
 #include <QPainter>
-#include <QPixmap>
+//#include <QPixmap>
 #include <QList>
 
 // For debugging output: Uncomment the fprintf section.
@@ -162,11 +162,8 @@ void MidiEditor::switchInfo(int n)
                   // Leave broadcasting changes to other selected tracks off.
                   
                   // Set focus yielding to the canvas.
-                  if(MusEGlobal::config.smartFocus)
-                  {
-                    w->setFocusYieldWidget(canvas);
-                    //w->setFocusPolicy(Qt::WheelFocus);
-                  }
+                  w->setFocusYieldWidget(canvas);
+                  //w->setFocusPolicy(Qt::WheelFocus);
 
                   // We must marshall song changed instead of connecting to the strip's song changed
                   //  otherwise it crashes when loading another song because track is no longer valid
