@@ -34,8 +34,8 @@
 #include "synth.h"
 #include "app.h"
 #include "song.h"
-#include "menutitleitem.h"
-#include "icons.h"
+//#include "menutitleitem.h"
+//#include "icons.h"
 #include "track.h"
 #include "drummap.h"
 #include "audio.h"
