@@ -389,7 +389,7 @@ void AudioTrack::processTrackCtrls(unsigned pos, int trackChans, unsigned nframe
       ciCtrlList icl = cll->begin();
       for(unsigned long k = 0; k < _controlPorts; ++k)
       {
-        CtrlList* cl = (icl != cll->end() ? icl->second : NULL);
+        CtrlList* cl = (icl != cll->end() ? icl->second : nullptr);
         CtrlInterpolate& ci = _controls[k].interp;
         // Always refresh the interpolate struct at first, since things may have changed.
         // Or if the frame is outside of the interpolate range - and eStop is not true.  // FIXME TODO: Be sure these comparisons are correct.
@@ -527,7 +527,7 @@ void AudioTrack::processTrackCtrls(unsigned pos, int trackChans, unsigned nframe
         const double down_fact = 0.996540262;
 
         float *sp1, *sp2, *dp1, *dp2;
-        sp1 = sp2 = dp1 = dp2 = NULL;
+        sp1 = sp2 = dp1 = dp2 = nullptr;
         double _volume, v, _pan, v1, v2;
 
         if(trackChans == 1)
@@ -2291,11 +2291,11 @@ void AudioTrack::setTotalOutChannels(int num)
             if(_dataBuffers[i])
             {
               free(_dataBuffers[i]);
-              _dataBuffers[i] = NULL;
+              _dataBuffers[i] = nullptr;
             }
           }
           delete[] _dataBuffers;
-          _dataBuffers = NULL;
+          _dataBuffers = nullptr;
         }
 
         _totalOutChannels = num;
@@ -2314,11 +2314,11 @@ void AudioTrack::setTotalOutChannels(int num)
               if(outBuffers[i])
               {
                 free(outBuffers[i]);
-                outBuffers[i] = NULL;
+                outBuffers[i] = nullptr;
               }
             }
             delete[] outBuffers;
-            outBuffers = NULL;
+            outBuffers = nullptr;
           }
         }
 
