@@ -33,8 +33,8 @@
 #include "wave.h"
 #include "midiport.h"
 #include "drummap.h"
-#include "midictrl.h"
-#include "gconfig.h"
+//#include "midictrl.h"
+//#include "gconfig.h"
 #include "config.h"
 
 // Forwards from header:
@@ -203,7 +203,7 @@ void Part::rechainClone()
     if(_backupClone)
     {
         this->chainClone(_backupClone);
-        _backupClone = NULL;
+        _backupClone = nullptr;
     }
 }
 
@@ -592,7 +592,7 @@ void Song::addPart(Part* part)
 #else
       if (epos > len())
 #endif
-        _len = epos;
+        _songLenTicks = epos;
 
       part->track()->addPart(part);
       
@@ -715,7 +715,7 @@ void Song::changePart(Part* oPart, Part* nPart)
       // adjust song len:
       unsigned int epos = nPart->tick() + nPart->lenTick();
       if (epos > len())
-            _len = epos;
+            _songLenTicks = epos;
       }
 
 //---------------------------------------------------------
