@@ -206,7 +206,7 @@ class Plugin {
       virtual void range(unsigned long i, float*, float*) const;
       virtual CtrlValueType ctrlValueType(unsigned long i) const;
       virtual CtrlList::Mode ctrlMode(unsigned long i) const;
-      virtual CtrlEnumValues* ctrlEnumValues ( unsigned long ) const;
+      virtual const CtrlEnumValues* ctrlEnumValues ( unsigned long ) const;
 
       virtual const char* portName(unsigned long i) {
             return plugin ? plugin->PortNames[i] : 0;
@@ -404,7 +404,7 @@ class PluginIBase
       virtual void setCustomData(const std::vector<QString> &) {/* Do nothing by default */}
       virtual CtrlValueType ctrlValueType(unsigned long i) const = 0;
       virtual CtrlList::Mode ctrlMode(unsigned long i) const = 0;
-      virtual CtrlEnumValues *ctrlEnumValues(unsigned long i) const;
+      virtual const CtrlEnumValues *ctrlEnumValues(unsigned long i) const;
       virtual QString portGroup(long unsigned int i) const;
       virtual bool ctrlIsTrigger(long unsigned int i) const;
       virtual bool ctrlNotOnGui(long unsigned int i) const;
@@ -572,7 +572,7 @@ class PluginI : public PluginIBase {
       unsigned long latencyOutPortIndex() const { return _latencyOutPort; }
       float latency() const;
       CtrlValueType ctrlValueType(unsigned long i) const { return _plugin->ctrlValueType(controls[i].idx); }
-      CtrlEnumValues* ctrlEnumValues( unsigned long i) const { return _plugin->ctrlEnumValues(controls[i].idx); }
+      const CtrlEnumValues* ctrlEnumValues( unsigned long i) const { return _plugin->ctrlEnumValues(controls[i].idx); }
       CtrlList::Mode ctrlMode(unsigned long i) const { return _plugin->ctrlMode(controls[i].idx); }
       virtual void setCustomData(const std::vector<QString> &customParams);
       };
@@ -602,14 +602,14 @@ class Pipeline : public std::vector<PluginI*> {
       bool isDssiPlugin(int) const;
       bool isLV2Plugin(int idx) const;
       bool isVstNativePlugin(int idx) const;
-      bool has_dssi_ui(int idx) const;
+      bool hasNativeGui(int idx) const;
       void showNativeGui(int, bool);
       void deleteGui(int idx);
       void deleteAllGuis();
       bool guiVisible(int);
       bool nativeGuiVisible(int);
       void apply(unsigned pos, unsigned long ports, unsigned long nframes, float** buffer);
-      void move(int idx, bool up);
+      void move(int idx1, int idx2);
       bool empty(int idx) const;
       void setChannels(int);
       bool addScheduledControlEvent(int track_ctrl_id, double val, unsigned frame); // returns true if event cannot be delivered
