@@ -296,14 +296,14 @@ void Audio::msgSetChannels(AudioTrack* node, int n)
       }
 
 //---------------------------------------------------------
-//   msgSwapControllerIDX
+//   msgSwapPlugins
 //---------------------------------------------------------
 
-void Audio::msgSwapControllerIDX(AudioTrack* node, int idx1, int idx2)
+void Audio::msgSwapPlugins(AudioTrack* node, int idx1, int idx2)
 {
       AudioMsg msg;
       
-      msg.id     = AUDIO_SWAP_CONTROLLER_IDX;
+      msg.id     = AUDIO_SWAP_PLUGINS;
       msg.snode  = node;
       msg.a      = idx1;
       msg.b      = idx2;
