@@ -696,7 +696,6 @@ class AudioTrack : public Track {
 
       void addController(CtrlList*);
       void removeController(int id);
-      void swapControllerIDX(int idx1, int idx2);
 
       bool readProperties(Xml&, const QString&);
       void writeProperties(int, Xml&) const;
@@ -708,6 +707,7 @@ class AudioTrack : public Track {
       void setRecFile(SndFileR sf)       { _recFile = sf; }
 
       CtrlListList* controller()         { return &_controller; }
+      const CtrlListList* controller() const { return &_controller; }
       // For setting/getting the _controls 'port' values.
       unsigned long parameters() const { return _controlPorts; }
       
@@ -763,6 +763,8 @@ class AudioTrack : public Track {
       void addPlugin(PluginI* plugin, int idx);
       // Assigns valid ID and track to plugin, and creates controllers for plugin.
       void setupPlugin(PluginI* plugin, int idx);
+      // Swaps plugins at slots idx1 and idx2, including empty slots.
+      void swapPlugins(int idx1, int idx2);
 
       double pluginCtrlVal(int ctlID) const;
       void setPluginCtrlVal(int param, double val);
