@@ -24,14 +24,14 @@
 //
 //=========================================================
 
-#include <stdio.h>
+//#include <stdio.h>
 #include "knob.h"
 #include "muse_math.h"
 #include "mmath.h"
 
 #include <QPainter>
 #include <QPalette>
-#include <QPaintEvent>
+//#include <QPaintEvent>
 #include <QResizeEvent>
 
 // For debugging output: Uncomment the fprintf section.
@@ -378,7 +378,7 @@ void Knob::getScrollMode( QPoint &p, const Qt::MouseButton &button, const Qt::Ke
 {
   // If modifier or button is held, jump directly to the position at first.
   // After handling it, the caller can change to SrcMouse scroll mode.
-  if(modifiers & Qt::ControlModifier || button == Qt::MidButton)
+  if(modifiers & Qt::ControlModifier || button == Qt::MiddleButton)
     {
       scrollMode = ScrDirect;
       direction = 0;
