@@ -20,15 +20,15 @@
 //
 //=========================================================
 
-#include <stdio.h>
+//#include <stdio.h>
 #include "knob_and_meter.h"
 #include "muse_math.h"
-#include "mmath.h"
+//#include "mmath.h"
 
 #include <QPainter>
 #include <QPainterPath>
 #include <QPalette>
-#include <QPaintEvent>
+//#include <QPaintEvent>
 #include <QResizeEvent>
 
 namespace MusEGui {
@@ -327,7 +327,7 @@ void KnobWithMeter::drawKnob(QPainter* p, const QRect& r)
 
 void KnobWithMeter::mousePressEvent(QMouseEvent *e)
 {
-//   if (e->button() == Qt::MidButton || e->modifiers() & Qt::ControlModifier) {
+//   if (e->button() == Qt::MiddleButton || e->modifiers() & Qt::ControlModifier) {
 //     int xpos = e->x() - width() /2;
 //     double v = float(e->y()) / height() * 1.2;
 // 
